MocTable class
Constructors
- MocTable()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createTable(
) → Future< void> -
inherited
-
createTableString(
) → String -
override
-
delete(
String shippingNoteNumber) → Future - 删除数据
-
deleteAll(
) → Future - 删除所有运单数据
-
getDatabase(
) → Future< Database> -
inherited
-
getTableList(
) → Future< List< Map< >String, dynamic> > - 读取数据
-
insert(
List< ShopInfo> list) → Future - 写入数据
-
isTableExits(
) → Future< bool> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tableName(
) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited