ShopInfo class
Constructors
- ShopInfo({String? driverName, String? endCountrySubdivisionCode, double? endLatitude, String? endLocationText, double? endLongitude, String? shippingNoteNumber, String? startCountrySubdivisionCode, double? startLatitude, String? startLocationText, double? startLongitude, String? vehicleNumber})
-
ShopInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- driverName ↔ String?
-
getter/setter pair
- endCountrySubdivisionCode ↔ String?
-
getter/setter pair
- endLatitude ↔ double?
-
getter/setter pair
- endLocationText ↔ String?
-
getter/setter pair
- endLongitude ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingNoteNumber ↔ String?
-
getter/setter pair
- startCountrySubdivisionCode ↔ String?
-
getter/setter pair
- startLatitude ↔ double?
-
getter/setter pair
- startLocationText ↔ String?
-
getter/setter pair
- startLongitude ↔ double?
-
getter/setter pair
- vehicleNumber ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - 因为sqlite 持久化的字段是以我们数据字段命名的,所以在toJson时有所不同 不同的字段为 endAddress、endSubdivisionCode、startAddress、startSubdivisionCode
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited